@@ -1,19 +1,22 @@
-def simple_exception():
+from __future__ import annotations
+
+
+def simple_exception() -> None:
     raise ValueError("Simple Exception")
 
 
-def nested_exception():
+def nested_exception() -> None:
     try:
         simple_exception()
     except ValueError:
         raise RuntimeError("Nested Exception")
 
 
-def recursive_exception():
-    def inner():
+def recursive_exception() -> None:
+    def inner() -> None:
         outer()
 
-    def outer():
+    def outer() -> None:
         inner()
 
     inner()
